#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tls-session-manager
version:              0.0.4
visibility:           public
id:                   tls-session-manager-0.0.4-8CVsC5TgjAkAybtgwDrjoR
key:                  tls-session-manager-0.0.4-8CVsC5TgjAkAybtgwDrjoR
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance

category:             Web
abi:                  a05cb90fbcabddbda1b8be27f9a52500
exposed:              True
exposed-modules:      Network.TLS.SessionManager
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-8.10.5/site-local/tls-session-manager-0.0.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tls-session-manager-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tls-session-manager-0.0.4
hs-libraries:         HStls-session-manager-0.0.4-8CVsC5TgjAkAybtgwDrjoR
depends:
    auto-update-0.1.6-7K4JToCmNkHJlkSexgjzA2 base-4.14.2.0
    basement-0.0.12-I5rgpQyLmajwT0dUlA8hE bytestring-0.10.12.0
    clock-0.8.2-CUh6FGzlB8CArRlXh1LKmY
    memory-0.16.0-E1gXzMJzgEcJ8QhI9dLs6S
    psqueues-0.2.7.2-JTDb6i4jgYCAzVhYduMDiO
    tls-1.5.5-3PUcwYgzKPF3oXwCgpwp46

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

